export default {
    "index": 0,
    "lineNumber": 1,
    "column": 1,
    "message": "Illegal 'use strict' directive in function with non-simple parameter list"
};
